@@ -1,6 +1,6 @@
 #######################################################################
 # seriation - Infrastructure for seriation
-# Copyrigth (C) 2015 Michael Hahsler, Christian Buchta and Kurt Hornik
+# Copyright (C) 2015 Michael Hahsler, Christian Buchta and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,10 +17,64 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-## registers seriation methods and criteria from package DendSer
-
+#' Register Seriation Methods from Package DendSer
+#'
+#' Register the DendSer dendrogram seriation method and the ARc criterion
+#' (Earle and Hurley, 2015) for use with [seriate()].
+#'
+#' Registers the method \code{"DendSer"} for [seriate()]. DendSer is a fast
+#' heuristic for reordering dendrograms developed by Earle and Hurley (2015)
+#' able to use different criteria.
+#'
+#' \code{control} for \code{seriate} with
+#' method \code{"DendSer"} accepts the following parameters:
+#'
+#' - "h" or "method" A dendrogram or a method for hierarchical clustering
+#'   (see \code{hclust}). Default: complete-link.
+#' - "criterion" A seriation criterion to optimize (see
+#'   \code{list_criterion_methods("dist")}). Default: \code{"BAR"} (Banded
+#'   anti-Robinson from with 20\% band width).}
+#' - "verbose" a logical; print progress information?
+#' - "DendSer_args" additional arguments for \code{DendSer}.
+#'
+#' For convenience, the following methods (for different cost functions) are
+#' also provided: \code{"DendSer_ARc"} (anti-robinson form),
+#' \code{"DendSer_BAR"} (banded anti-Robinson form), \code{"DendSer_LS"} (leaf
+#' seriation), \code{"DendSer_PL"} (path length).
+#'
+#' Note: Package \pkg{DendSer} needs to be installed.
+#'
+#' @aliases register_DendSer DendSer dendser
+#' @family seriation
+#' @returns Nothing.
+#'
+#' @author Michael Hahsler based on code by Catherine B. Hurley and Denise
+#' Earle
+#' @references D. Earle, C. B. Hurley (2015): Advances in dendrogram seriation
+#' for application to visualization. \emph{Journal of Computational and
+#' Graphical Statistics,} \bold{24}(1), 1--25.
+#' @keywords optimize cluster
+#' @examples
+#'
+#' \dontrun{
+#' register_DendSer()
+#' get_seriation_method("dist", "DendSer")
+#'
+#' d <- dist(random.robinson(20, pre=TRUE))
+#'
+#' ## use Banded AR form with default clustering (complete-link)
+#' o <- seriate(d, "DendSer_BAR")
+#' pimage(d, o)
+#'
+#' ## use different hclust method (Ward) and AR as the cost function for
+#' ## dendrogram reordering
+#' o <- seriate(d, "DendSer", control = list(method = "ward.D2", criterion = "AR"))
+#' pimage(d, o)
+#' }
+#'
+#' @export
 register_DendSer <- function() {
-  if(!.installed("DendSer")) stop("Package 'DendSer' needs to be  installed!")
+  check_installed("DendSer")
 
   ## seriation methods
 
@@ -45,18 +99,18 @@ register_DendSer <- function() {
     control <- .get_parameters(control, .DendSer_control)
 
     ## fix cost if it is a criterion from seriation
-    if(!is.null(control$criterion))
+    if (!is.null(control$criterion))
       control$cost <- DendSer::crit2cost(crit = control$criterion)
 
     ## produce hclust
-    if(is.null(control$h))
+    if (is.null(control$h))
       control$h <- hclust(x, control$method)
 
     control$method <- NULL
     control$criterion <- NULL
     control$ser_weight <- x
 
-    if(!is.null(control$DendSer_args)) {
+    if (!is.null(control$DendSer_args)) {
       control <- c(control, control$DendSer_args)
       control$DendSer_args <- NULL
     }
@@ -92,17 +146,40 @@ register_DendSer <- function() {
   #    DendSer_helper(as.matrix(x)[,1], control)
   #  }
 
-  seriation::set_seriation_method("dist", "DendSer",
-    DendSer_helper, "Dendrogram seriation (Earle and Hurley, 2015).", .DendSer_control)
+  seriation::set_seriation_method(
+    "dist",
+    "DendSer",
+    DendSer_helper,
+    "Dendrogram seriation (Earle and Hurley, 2015).",
+    .DendSer_control
+  )
 
-  seriation::set_seriation_method("dist", "DendSer_BAR",
-    DendSer_BAR, "Dendrogram seriation  with BAR (Earle and Hurley, 2015).", .DendSer_control)
-  seriation::set_seriation_method("dist", "DendSer_PL",
-    DendSer_PL, "Dendrogram seriation (Path length)", .DendSer_control)
-  seriation::set_seriation_method("dist", "DendSer_LPL",
-    DendSer_PL, "Dendrogram seriation (Lazy path length)", .DendSer_control)
-  seriation::set_seriation_method("dist", "DendSer_ARc",
-    DendSer_ARc, "Dendrogram seriation (ARc)", .DendSer_control)
+  seriation::set_seriation_method(
+    "dist",
+    "DendSer_BAR",
+    DendSer_BAR,
+    "Dendrogram seriation  with BAR (Earle and Hurley, 2015).",
+    .DendSer_control
+  )
+  seriation::set_seriation_method(
+    "dist",
+    "DendSer_PL",
+    DendSer_PL,
+    "Dendrogram seriation (Path length)",
+    .DendSer_control
+  )
+  seriation::set_seriation_method(
+    "dist",
+    "DendSer_LPL",
+    DendSer_PL,
+    "Dendrogram seriation (Lazy path length)",
+    .DendSer_control
+  )
+  seriation::set_seriation_method("dist",
+    "DendSer_ARc",
+    DendSer_ARc,
+    "Dendrogram seriation (ARc)",
+    .DendSer_control)
   #  seriation::set_seriation_method("dist", "DendSer_LS",
   #    DendSer_LS, "Dendrogram seriation (Leaf sort)")
 
@@ -111,9 +188,11 @@ register_DendSer <- function() {
 
   DendSer_crit_ARc <- function(x, order, ...) {
     x <- as.matrix(x)
-    if (is.null(order)) order <- 1:nrow(x)
-    else order <- get_order(order)
-    DendSer::costARc(x,order,...)
+    if (is.null(order))
+      order <- 1:nrow(x)
+    else
+      order <- get_order(order)
+    DendSer::costARc(x, order, ...)
   }
 
   seriation::set_criterion_method("dist", "ARc", DendSer_crit_ARc,
