@@ -30,7 +30,7 @@ seriate_dist_chen <- function(x, control = NULL) {
   ## find the first correlation matrix of rank 2
   n <- 0
   while (rank > 2) {
-    x <- cor(x)
+    x <- stats::cor(x)
     n <- n + 1
     rank <- qr(x)$rank
   }
@@ -50,7 +50,6 @@ seriate_dist_chen <- function(x, control = NULL) {
   left <- left[order(e[left, 2])]
 
   o <- c(right, left)
-  names(o) <- labels(x)[o]
   o
 }
 
